package edu.travel.commodity.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import edu.travel.commodity.entity.ShopAddress;
import edu.travel.commodity.mapper.ShopAddressMapper;
import edu.travel.commodity.service.ShopAddressService;
import edu.travel.commodity.utils.PageUtil;
import edu.travel.commodity.utils.TokenData;
import edu.travel.remote.dto.BaseDto;
import edu.travel.remote.dto.UpdateAddressDto;
import edu.travel.remote.vo.ShopAddressVo;
import org.springframework.stereotype.Service;


@Service
public class ShopAddressServiceImpl extends ServiceImpl<ShopAddressMapper, ShopAddress> implements ShopAddressService {

    @Override
    public Page<ShopAddressVo> getShopAddress(BaseDto dto) {
        //当前登录对象
        LambdaQueryWrapper<ShopAddress> query = Wrappers.<ShopAddress>lambdaQuery().eq(ShopAddress::getCountryId, dto.getCountryId())
                .eq(ShopAddress::getUserId, TokenData.getUserId())
                .orderByAsc(ShopAddress::getIsDefault);
        Page<ShopAddress> page = page(new Page<ShopAddress>(dto.getCurrentPage(), dto.getPageSize()), query);
        //page对象转换.
        return PageUtil.toPageEntity(page, ShopAddressVo.class);
    }

    @Override
    public boolean updateAddressById(UpdateAddressDto param) {
        String userId = TokenData.getUserId();
        if (!ObjectUtil.isEmpty(param.getCountryId())) {
//            BaseCountry byId = baseCountryService.getById(param.getCountryId());
//            if(byId==null){
//                throw new BaseException("国家不存在");
//            }
        }
        LambdaQueryWrapper<ShopAddress> query = Wrappers.<ShopAddress>lambdaQuery().eq(ShopAddress::getId, param.getId())
                .eq(ShopAddress::getUserId, userId);
        ShopAddress one = getOne(query);
        if (one == null) {//新增
            ShopAddress bean = BeanUtil.toBean(param, ShopAddress.class);
            bean.setUserId(Long.valueOf(userId));
            return save(bean);
        }
        if (!ObjectUtil.isEmpty(param.getCountryId())) {
            //修改国家ID
            one.setCountryId(Long.valueOf(param.getCountryId()));
        }
        if (!ObjectUtil.isEmpty(param.getRecipientName())) {
            //修改收货人名称
            one.setRecipientName(param.getRecipientName());
        }
        if (!ObjectUtil.isEmpty(param.getPhone())) {
            //修改收货人手机号
            one.setPhone(param.getPhone());
        }
        if (!ObjectUtil.isEmpty(param.getDetailedAddress())) {
            //修改详细地址
            one.setDetailedAddress(param.getDetailedAddress());
        }
        if (!ObjectUtil.isEmpty(param.getIsDefault())) {
            //修改详细地址
            one.setIsDefault(param.getIsDefault());
        }
        return updateById(one);
    }
}
