package edu.travel.commodity.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import edu.travel.commodity.constant.BaseConstant;
import edu.travel.commodity.entity.ShopProduct;
import edu.travel.commodity.mapper.ShopProductMapper;
import edu.travel.commodity.service.*;
import edu.travel.commodity.utils.PageUtil;
import edu.travel.exception.BaseException;
import edu.travel.remote.dto.*;
import edu.travel.remote.vo.ShopProductVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.io.IOException;
import java.util.List;

@Service
public class ShopProductServiceImpl extends ServiceImpl<ShopProductMapper, ShopProduct> implements ShopProductService {
    @Autowired
    private ShopProductImageService shopProductImageService;

    @Autowired
    private ShopProductSkuService shopProductSkuService;

    @Autowired
    private ShopProductSpecService shopProductSpecService;

    @Autowired
    private ShopProductParametersService shopProductParametersService;

    @Autowired
    private ShopSpecService shopSpecService;

    @Override
    public Page<ShopProductVo> getHotProduct(GetProductByTypeDto type) {
        LambdaQueryWrapper<ShopProduct> query = Wrappers.<ShopProduct>lambdaQuery()
                .eq(ShopProduct::getStatus, BaseConstant.BASIC_STATUS_NO_NUM)
                .eq(ShopProduct::getCountryId, type.getCountryId());

        if (!ObjectUtil.isEmpty(type.getType())) {
            query.eq(ShopProduct::getCategoryId, type.getType());
        }
        query.orderByDesc(ShopProduct::getHeatValue);
        Page<ShopProduct> shopProductPage = baseMapper.selectPage(new Page<ShopProduct>(type.getCurrentPage(), type.getPageSize()), query);

        return PageUtil.toPageEntity(shopProductPage, ShopProductVo.class);
    }

    @Override
    public Page<ShopProductVo> searchProduct(SearchProductDto param) throws IOException {

        return null;
    }

    @Override
    @Transactional
    public void insertProduct(InsertProductDto params) {
        ShopProduct bean = BeanUtil.toBean(params, ShopProduct.class);
        if (ObjectUtil.isEmpty(params.getImages())) {
            throw new BaseException("至少需要一张图片");
        }
        List<FileDto> images = params.getImages();
        bean.setMainImageUrl(images.get(0).getFilePath());
        //保存商品
        this.save(bean);
        List<InsertProductSpecDto> specs = params.getSpecs();

        //保存商品规格和规格值
        boolean b1 = shopProductSpecService.insertProductSpec(specs, bean);

        //保存商品图片
        boolean b2 = shopProductImageService.saveProductImage(bean.getId(), images);

        //添加一个空的sku
        boolean b3 = shopProductSkuService.insertProductSku(params.getSpecs(), params.getSkus(), bean);

        //保存商品参数
        boolean b4 = shopProductParametersService.insertProductParameters(params.getParameters(), bean);
        //TODO 同步到es
    }
}
