package edu.travel.commodity.web;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.commodity.entity.ShopFavorite;
import edu.travel.commodity.service.ShopFavoriteService;
import edu.travel.commodity.utils.TokenData;
import edu.travel.remote.commodity.ShopFavoriteRemoteController;
import edu.travel.remote.dto.AddFavoriteDto;
import edu.travel.remote.dto.BaseDto;
import edu.travel.remote.vo.ShopFavoriteVo;
import edu.travel.rpc.RPCBaseResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Set;

import static edu.travel.rpc.RPCBaseResponse.success;

/**
 * 收藏表(shop_favorite)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/shopFavorite")
public class ShopFavoriteController implements ShopFavoriteRemoteController {
    /**
     * 服务对象
     */
    @Autowired
    private ShopFavoriteService shopFavoriteService;

    /**
     * 获取收藏商品
     *
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShopFavoriteVo }>>
     */
    @GetMapping("/getFavorite")
    public RPCBaseResponse<Page<ShopFavoriteVo>> getFavorite(BaseDto baseDto) {
        return success(shopFavoriteService.getFavorite(baseDto));
    }


    /**
     * 添加收藏
     *
     * @param params
     * @return {@link RPCBaseResponse }<{@link Void }>
     */

    @PostMapping("/addFavorite")
    public RPCBaseResponse<Void> addFavorite(@RequestBody AddFavoriteDto params) {
        shopFavoriteService.addFavorite(params);
        return success();
    }

    /**
     * 移除收藏
     */
    @PostMapping("/removeFavorite")
    public RPCBaseResponse<Void> removeFavorite(@RequestBody Set<String> ids) {
        shopFavoriteService.removeByIds(ids);
        return success();
    }

    /**
     * 全部移除
     */
    @PostMapping("/removeAllFavorite")
    public RPCBaseResponse<Void> removeAllFavorite() {
        LambdaQueryWrapper<ShopFavorite> query = Wrappers.<ShopFavorite>lambdaQuery().eq(ShopFavorite::getUserId, TokenData.getUserId());
        shopFavoriteService.remove(query);
        return success();
    }
}
