package edu.travel.country.web;


import com.baomidou.mybatisplus.core.metadata.IPage;
import edu.travel.country.entity.BaseCountryServe;
import edu.travel.country.service.BaseCountryServeService;
import edu.travel.country.service.BaseCountryService;
import edu.travel.dto.BaseCountryServeDto;
import edu.travel.dto.BaseCountryServeStatusDto;
import edu.travel.remote.BaseCountryServeRemoteController;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.vo.BaseCountryServeStatusVo;
import edu.travel.vo.BaseCountryServeVo;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 服务国家表(base_country_serve)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/baseCountryServe")
public class BaseCountryServeController extends BaseController<BaseCountryServe> implements BaseCountryServeRemoteController {

    /**
     * 服务国家表(base_country_serve)表控制层
     */
    @Autowired
    private BaseCountryServeService baseCountryServeService;
    @Autowired
    private BaseCountryService baseCountryService;

    /**
     * 分页连表
     */
    @GetMapping("/getCountryServeCurrencyPageForm")
    public RPCBaseResponse<IPage<BaseCountryServe>> getCountryServeCurrencyPageForm(BaseCountryServeDto dto) {
        return baseCountryServeService.getCountryServeCurrencyPageForm(dto);
    }

    /**
     * 服务国家状态更新
     */
    @PostMapping("/updateServeStatus")
    public RPCBaseResponse<BaseCountryServeStatusVo> updateServeStatus(@RequestBody BaseCountryServeStatusDto entity) {
        return baseCountryServeService.updateServeStatus(entity);
    }


    /**
     * 服务国家树
     */
    @GetMapping("/getCountryServeTree")
    public RPCBaseResponse<List<BaseCountryServeVo>> getCountryServeTree() {
        return baseCountryServeService.getCountryServeTree();
    }

    /**
     * 获取服务国家信息
     *
     * @param id
     * @return
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<BaseCountryServeVo> getFormId(@RequestParam("id") String id) {
        RPCBaseResponse<BaseCountryServe> baseCountryServeRPCBaseResponse = super.getId(id);
        RPCBaseResponse<BaseCountryServeVo> baseCountryServeVoPRCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(baseCountryServeRPCBaseResponse, baseCountryServeVoPRCBaseResponse);
        return baseCountryServeVoPRCBaseResponse;
    }

    /**
     * 更新服务国家信息
     *
     * @param entity
     * @return
     */
    @Override
    @PostMapping("/updateTargetFormId")
    public RPCBaseResponse<BaseCountryServeVo> updateTargetFormId(@RequestBody BaseCountryServeDto entity) {
        BaseCountryServe baseCountryServe = new BaseCountryServe();
        BeanUtils.copyProperties(entity, baseCountryServe);
        RPCBaseResponse<BaseCountryServe> baseCountryServeRPCBaseResponse = super.updateTargetById(baseCountryServe);
        RPCBaseResponse<BaseCountryServeVo> baseCountryServeVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(baseCountryServeRPCBaseResponse, baseCountryServeVoRPCBaseResponse);
        return baseCountryServeVoRPCBaseResponse;
    }

    /**
     * 新增服务国家信息
     *
     * @param entity
     * @return
     */
    @Override
    @PostMapping("/saveFormTarget")
    public RPCBaseResponse<BaseCountryServeVo> saveFormTarget(@RequestBody BaseCountryServeDto entity) {
        BaseCountryServe baseCountryServe = new BaseCountryServe();
        BeanUtils.copyProperties(entity, baseCountryServe);
        boolean save = baseCountryServeService.save(baseCountryServe);
        RPCBaseResponse<BaseCountryServeVo> baseCountryServeVoRPCBaseResponse = new RPCBaseResponse<>();
        BaseCountryServeVo countryServeVo = new BaseCountryServeVo();
        BeanUtils.copyProperties(baseCountryServe, countryServeVo);
        baseCountryServeVoRPCBaseResponse.setCode(200);
        baseCountryServeVoRPCBaseResponse.setMsg("");
        baseCountryServeVoRPCBaseResponse.setData(countryServeVo);
        return baseCountryServeVoRPCBaseResponse;
    }

    /**
     * 新增服务国家信息（new)
     */
    @PostMapping("/saveFormTargetNew")
    public RPCBaseResponse<BaseCountryServeVo> saveFormTargetNew(@RequestBody BaseCountryServeDto entity, HttpServletRequest request) {
        return baseCountryService.saveFormTargetNew(entity, request);
    }

    /**
     * 删除服务国家信息
     *
     * @param ids
     * @return
     */
    @Override
    @PostMapping("/deleteTargetFormId")
    public RPCBaseResponse<BaseCountryServeVo> deleteTargetFormId(@RequestBody List<String> ids) {
        RPCBaseResponse<BaseCountryServe> baseCountryServeRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<BaseCountryServeVo> baseCountryServeVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(baseCountryServeRPCBaseResponse, baseCountryServeVoRPCBaseResponse);
        return baseCountryServeVoRPCBaseResponse;
    }

    /**
     * 获取服务国家列表
     *
     * @return
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<BaseCountryServeVo>> getAllForm() {
        RPCBaseResponse<List<BaseCountryServe>> listRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<BaseCountryServeVo>> baseCountryServeVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(listRPCBaseResponse, baseCountryServeVoRPCBaseResponse);
        return baseCountryServeVoRPCBaseResponse;
    }
}
