package edu.travel.country.web;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import edu.travel.country.entity.ShopLanguage;
import edu.travel.country.service.ShopLanguageService;
import edu.travel.dto.ShopLanguageDto;
import edu.travel.dto.ShopLanguageWebAppupdateDto;
import edu.travel.remote.ShopLanguageRemoteController;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.vo.ShopLanguageVo;
import edu.travel.vo.ShopLanguageWebAppupdateVo;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 语言表(shop_language)表控制层
 *
 * @author xxxxx
 */
@RestController
@RequestMapping("/shopLanguage")
public class ShopLanguageController extends BaseController<ShopLanguage> implements ShopLanguageRemoteController {
    /**
     * 服务对象
     */
    @Autowired
    private ShopLanguageService shopLanguageService;

    /**
     * 语言分页
     */
    @GetMapping("/getLanguagePage")
    public RPCBaseResponse<IPage<ShopLanguageVo>> getLanguagePage(ShopLanguageDto shopLanguageDto) {
        return shopLanguageService.getLanguagePage(shopLanguageDto);
    }

    /**
     * 获取语言详情
     *
     * @param id
     * @return
     */
    @Override
    @GetMapping("/getFormId")
    public RPCBaseResponse<ShopLanguageVo> getFormId(@RequestParam("id") String id) {
        RPCBaseResponse<ShopLanguage> languageRPCBaseResponse = super.getId(id);
        RPCBaseResponse<ShopLanguageVo> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(languageRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }

    /**
     * 更新语言信息
     *
     * @param entity
     * @return
     */
    @Override
    @PostMapping("/updateTargetFormId")
    public RPCBaseResponse<ShopLanguageVo> updateTargetFormId(@RequestBody ShopLanguageDto entity) {
        ShopLanguage shopLanguage = new ShopLanguage();
        BeanUtils.copyProperties(entity, shopLanguage);
        RPCBaseResponse<ShopLanguage> languageRPCBaseResponse = super.updateTargetById(shopLanguage);
        RPCBaseResponse<ShopLanguageVo> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(languageRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }

    /**
     * 新增语言信息
     *
     * @param entity
     * @return
     */
    @Override
    @PostMapping("/saveFormTarget")
    public RPCBaseResponse<ShopLanguageVo> saveFormTarget(@RequestBody ShopLanguageDto entity) {
        ShopLanguage shopLanguage = new ShopLanguage();
        BeanUtils.copyProperties(entity, shopLanguage);
        RPCBaseResponse<ShopLanguage> languageRPCBaseResponse = super.saveTarget(shopLanguage);
        RPCBaseResponse<ShopLanguageVo> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(languageRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }

    /**
     * 删除语言
     *
     * @param ids
     * @return
     */
    @Override
    @PostMapping("/deleteTargetFormId")
    public RPCBaseResponse<ShopLanguageVo> deleteTargetFormId(@RequestBody List<String> ids) {
        RPCBaseResponse<ShopLanguage> languageRPCBaseResponse = super.deleteTargetById(ids);
        RPCBaseResponse<ShopLanguageVo> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(languageRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }

    /**
     * 获取语言表
     *
     * @return
     */
    @Override
    @GetMapping("/getAllForm")
    public RPCBaseResponse<List<ShopLanguageVo>> getAllForm() {
        RPCBaseResponse<List<ShopLanguage>> listRPCBaseResponse = super.listAll();
        RPCBaseResponse<List<ShopLanguageVo>> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(listRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }

    /**
     * 三端状态改变
     */
    //转换类型
    @PostMapping("/updateAppStatus")
    public RPCBaseResponse<ShopLanguageWebAppupdateVo> updateAppStatus(@RequestBody ShopLanguageWebAppupdateDto ShopLanguageWebAppupdateDto) {
        ShopLanguage shopLanguage = BeanUtil.toBean(ShopLanguageWebAppupdateDto, ShopLanguage.class);
        RPCBaseResponse<ShopLanguage> languageRPCBaseResponse = super.updateTargetById(shopLanguage);
        RPCBaseResponse<ShopLanguageWebAppupdateVo> shopLanguageVoRPCBaseResponse = new RPCBaseResponse<>();
        BeanUtils.copyProperties(languageRPCBaseResponse, shopLanguageVoRPCBaseResponse);
        return shopLanguageVoRPCBaseResponse;
    }
}
