package edu.travel.education.web;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.education.dto.AddHappyEntryDto;
import edu.travel.education.dto.HappyEntryDto;
import edu.travel.education.entity.HappyEntry;
import edu.travel.education.service.impl.HappyEntryServiceImpl;
import edu.travel.education.vo.HappyEntryVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.web.BaseController;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * 开心中文报名表(happy_entry)表控制层
 *
 * @author huangwen
 */
@RestController
@RequestMapping("/happyEntry")
public class HappyEntryController extends BaseController<HappyEntry> {
    @Autowired
    private HappyEntryServiceImpl happyEntryService;

    /**
     * 添加报名表
     *
     * @param happyEntryDto
     * @return
     */
    @PostMapping("/addHappyEntry")
    @PreAuthorize("permitAll()")
    public RPCBaseResponse<HappyEntryVo> addHappyEntry(@Valid @RequestBody AddHappyEntryDto happyEntryDto) {
        HappyEntryVo vo = happyEntryService.addHappyEntry(happyEntryDto);
        HappyEntry oneLink = happyEntryService.getOneLink(new LambdaQueryWrapper<HappyEntry>().eq(HappyEntry::getId, vo.getId()));
        HappyEntryVo happyEntryVo = BeanUtil.copyProperties(oneLink, HappyEntryVo.class);
        return new RPCBaseResponse<>(200, "success", happyEntryVo);
    }

    /**
     * 根据id查询报名表详情
     *
     * @param id
     * @return
     */
    @GetMapping("/getHappyEntryById")
    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<HappyEntryVo> getHappyEntryById(Long id) {
        HappyEntryVo vo = happyEntryService.getHappyEntryById(id);
        return new RPCBaseResponse<>(200, "success", vo);
    }

    /**
     * 根据id修改报名表
     *
     * @param happyEntryDto
     * @return
     */
    @PostMapping("/UpdateHappyEntryById")
    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<HappyEntryVo> UpdateHappyEntryById(@RequestBody HappyEntryDto happyEntryDto) {
        HappyEntryVo vo = happyEntryService.UpdateHappyEntryById(happyEntryDto);
        return new RPCBaseResponse<>(200, "success", vo);
    }

    /**
     * 根据id删除报名表
     *
     * @param id
     * @return
     */
    @PostMapping("/deleteHappyEntryById")
    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<HappyEntryVo> deleteHappyEntryById(@RequestParam Long id) {
        Set<Long> set = new HashSet<>();
        set.add(id);
        happyEntryService.deleteHappyEntryByIds(set);
        return new RPCBaseResponse<>(200, "success", null);
    }

    /**
     * 根据ids批量删除报名表
     *
     * @param ids
     * @return
     */
    @PostMapping("/deleteHappyEntryByIds")
    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<HappyEntryVo> deleteHappyEntryById(@RequestBody List<Long> ids) {
        Set<Long> set = new HashSet<Long>(ids);
        happyEntryService.deleteHappyEntryByIds(set);
        return new RPCBaseResponse<>(200, "success", null);
    }

    /**
     * 分页查询报名表
     *
     * @return
     */
    @GetMapping("/listPageHappyEntry")
    @PreAuthorize("hasRole('超级管理员')")
    public RPCBaseResponse<Page<HappyEntryVo>> listPageHappyEntry(HappyEntryDto happyEntryDto) {
        IPage<HappyEntry> page = happyEntryService.listPageHappyEntry(happyEntryDto);
        List<HappyEntryVo> happyEntryVos = BeanUtil.copyToList(page.getRecords(), HappyEntryVo.class);
        Page<HappyEntryVo> target = new Page<HappyEntryVo>();
        BeanUtils.copyProperties(page, target);
        target.setRecords(happyEntryVos);
        return new RPCBaseResponse<>(200, "success", target);
    }

}
