package edu.travel.order.controller;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.order.entity.ShopOrder;
import edu.travel.order.service.ShopOrderService;
import edu.travel.remote.dto.AddOrderDto;
import edu.travel.remote.dto.GetOrderItemInfoByOrderNumDto;
import edu.travel.remote.dto.ShopOrderDto;
import edu.travel.remote.dto.ShowOrderInfoDto;
import edu.travel.remote.order.ShopOrderRemoteController;
import edu.travel.remote.vo.OrderItemVo;
import edu.travel.remote.vo.ShopOrderVo;
import edu.travel.remote.vo.ShowOrderInfoVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.web.BaseController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static edu.travel.rpc.RPCBaseResponse.success;


@RestController
@RequestMapping("/shopOrder")
public class ShopOrderController extends BaseController<ShopOrder> implements ShopOrderRemoteController {
    @Autowired
    private ShopOrderService shopOrderService;

    /**
     * 状态查询我的订单
     *
     * @param params
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/showOrderInfo")
    public RPCBaseResponse<Page<ShowOrderInfoVo>> showOrderInfo(ShowOrderInfoDto params) {
        return success(shopOrderService.showOrderInfo(params));
    }

    /**
     * 下单生成订单
     *
     * @return {@link RPCBaseResponse }<{@link Void }>
     */
    @Override
    @PostMapping("/addShopOrder")
    public RPCBaseResponse<Void> addShopOrder(@RequestBody AddOrderDto params) {
        shopOrderService.addShopOrder(params);
        return success();
    }

    /**
     * 查询订单下的商品快照
     *
     * @param params 订单号
     * @return {@link RPCBaseResponse }<{@link String }>
     */

    @GetMapping("/getOrderItemInfo")
    public RPCBaseResponse<Page<OrderItemVo>> getOrderItemInfo(GetOrderItemInfoByOrderNumDto params) {
        return RPCBaseResponse.success(shopOrderService.getOrderItemInfo(params));
    }

    /**
     * 通过订单号查询订单详情
     *
     * @param orderNum 订单号
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/orderInfoByOrderNum")
    public RPCBaseResponse<ShowOrderInfoVo> orderInfoByOrderNum(String orderNum) {
        return success(shopOrderService.orderInfoByOrderNum(orderNum));
    }

    /**
     * 修改订单状态
     *
     * @param orderNum 订单号 state 状态 OrderStateEnum
     * @return {@link RPCBaseResponse }<{@link Page }<{@link ShowOrderInfoVo }>>
     */
    @GetMapping("/changeOrderState")
    public RPCBaseResponse<Void> changeOrderState(String orderNum, String state) {
        shopOrderService.changeOrderState(orderNum, state);
        return success();
    }

    /**
     * 订单号查询订单
     *
     * @param id
     * @return {@link RPCBaseResponse }<{@link ShopOrderVo }>
     */

    @GetMapping("/getFormId")
    public RPCBaseResponse<ShopOrderVo> getFormId(@RequestParam("id") String id) {
        LambdaQueryWrapper<ShopOrder> query = Wrappers.<ShopOrder>lambdaQuery().eq(ShopOrder::getOrderNumber, id);
        ShopOrder byId = shopOrderService.getOne(query);
        ShopOrderVo bean = BeanUtil.toBean(byId, ShopOrderVo.class);
        return success(bean);
    }

    @Override
    public RPCBaseResponse<ShopOrderVo> updateTargetFormId(ShopOrderDto entity) {
        return null;
    }

    @Override
    public RPCBaseResponse<ShopOrderVo> saveFormTarget(ShopOrderDto entity) {
        return null;
    }

    @Override
    public RPCBaseResponse<ShopOrderVo> deleteTargetFormId(List<String> ids) {
        return null;
    }

    @Override
    public RPCBaseResponse<List<ShopOrderVo>> getAllForm() {
        return null;
    }
}
