package edu.travel.tenant.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.lang.Snowflake;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import edu.travel.RSAUtill;
import edu.travel.remote.feign.mode.dto.tenant.SysProjectDto;
import edu.travel.remote.feign.mode.vo.tenant.SysProjectVo;
import edu.travel.tenant.entity.SysProject;
import edu.travel.tenant.mapper.SysProjectMapper;
import edu.travel.tenant.service.SysProjectService;
import org.modelmapper.internal.util.Assert;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Map;

@Service
public class SysProjectServiceImpl extends ServiceImpl<SysProjectMapper, SysProject> implements SysProjectService {

    @Override
    @Transactional
    public SysProjectVo saveProject(SysProjectDto sysProjectDto) {
        Assert.isTrue(ObjectUtil.isNotEmpty(sysProjectDto.getProjectNameCn()), "项目名不能为空");
        Assert.isTrue(ObjectUtil.isNotEmpty(sysProjectDto.getProjectNameEn()), "项目名不能为空");

        SysProject sysProject = BeanUtil.copyProperties(sysProjectDto, SysProject.class);
        sysProject.setProject(new Snowflake(1, 1).nextIdStr());

        Map<String, String> keyPair = RSAUtill.generateKeyPair();
        sysProject.setPublicKey(keyPair.get("publicKey"));
        sysProject.setPrivateKey(keyPair.get("privateKey"));
        this.save(sysProject);
        return BeanUtil.copyProperties(sysProject, SysProjectVo.class);
    }

    @Override
    public IPage<SysProject> getProjectPageList(SysProjectDto sysProjectDto) {
        IPage<SysProject> sysProjectPage = new Page<>(sysProjectDto.getCurrentPage() == null ? 1 : sysProjectDto.getCurrentPage(), sysProjectDto.getPageSize() == null ? 10 : sysProjectDto.getPageSize());
        IPage<SysProject> sysProjectIPage = this.baseMapper.selectPage(sysProjectPage, null);
        return sysProjectIPage;
    }
}
