package edu.travel.tenant.web;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import edu.travel.remote.feign.mode.dto.tenant.AddMenuDto;
import edu.travel.remote.feign.mode.dto.tenant.SysMenuPageDto;
import edu.travel.remote.feign.mode.vo.tenant.AddMenuVo;
import edu.travel.remote.feign.mode.vo.tenant.MenuTreeVo;
import edu.travel.resp.BaseResponse;
import edu.travel.resp.PageResponse;
import edu.travel.tenant.SysMenuRemoteController;
import edu.travel.tenant.entity.SysMenu;
import edu.travel.tenant.service.ISysMenuService;
import edu.travel.web.BaseController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Collections;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * SysMenuController 类。
 * <p>
 * 描述：
 *
 * @author huangwenwen
 * @date 2025/2/6
 */

@RestController
@RequestMapping("/sysMenu")
public class SysMenuController extends BaseController<SysMenu> implements SysMenuRemoteController {
    @Autowired
    private ISysMenuService sysMenuService;

    /**
     * 新增菜单
     *
     * @param addMenuDto
     * @return
     */
    @PostMapping("/addMenu")
//@PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<AddMenuVo> addMenu(@RequestBody AddMenuDto addMenuDto) {
        AddMenuVo addMenuVo = sysMenuService.addMenu(addMenuDto);
        return new BaseResponse<>(200, "sucess", addMenuVo);
    }

    /**
     * 删除菜单单个
     *
     * @param id
     * @return
     */

    @PostMapping("/deleteMenuById")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteMenuById(@RequestParam Long id) {
        Set<Long> longs = new HashSet<>();
        longs.add(id);
        sysMenuService.deleteMenuByIds(longs);
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 删除菜单多个
     *
     * @param ids
     * @return
     */
    @PostMapping("/deleteMenuByIds")
//    @PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> deleteMenuByIds(@RequestBody List<Long> ids) {
        HashSet<Long> set = new HashSet<>(ids);
        sysMenuService.deleteMenuByIds(set);
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 获取菜单分页树形列表
     *
     * @param sysMenuPageDto
     * @return
     */
    @GetMapping("/getMenuTreeListAll")
//@PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<List<MenuTreeVo>> getMenuTreeListAll(SysMenuPageDto sysMenuPageDto) {
        IPage<SysMenu> page = new Page<>(sysMenuPageDto.getCurrentPage(), sysMenuPageDto.getPageSize());
        IPage<SysMenu> sysMenuIPage = sysMenuService.page(page, new LambdaQueryWrapper<SysMenu>().eq(SysMenu::getDeleteFlag, 0).like(StringUtils.isNotBlank(sysMenuPageDto.getTitle()), SysMenu::getTitle, sysMenuPageDto.getTitle()));
        List<MenuTreeVo> treeList = sysMenuService.getMenuTreeListAll(sysMenuIPage.getRecords());
        return PageResponse.out(200, "success", treeList, (int) sysMenuIPage.getTotal(), (int) sysMenuIPage.getSize());
    }

    /**
     * 通过菜单id修改菜单
     *
     * @param updateMenuDto
     * @return
     */
    @PostMapping("/updateMenuById")
//@PreAuthorize("hasRole('超级管理员')")
    public BaseResponse<Boolean> updateMenuById(@RequestBody AddMenuDto updateMenuDto) {
        sysMenuService.updateMenuById(updateMenuDto);
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 启用菜单单个
     *
     * @param id
     * @return
     */
    @PostMapping("/enableMenuSingle")
    public BaseResponse enableMenuSingle(@RequestParam Long id) {
        Assert.isTrue(ObjectUtil.isNotEmpty(id), "请选择菜单");
        sysMenuService.enableMenuByIds(new HashSet<>(Collections.singletonList(id)));
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 启用菜单多个
     */
    @PostMapping("/enableMenuMulti")
    public BaseResponse enableMenuMulti(@RequestBody List<Long> ids) {
        sysMenuService.enableMenuByIds(new HashSet<Long>(ids));
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 禁用菜单单个
     */
    @PostMapping("/disableMenuSingle")
    public BaseResponse disableMenuSingle(@RequestParam Long id) {
        Assert.isTrue(ObjectUtil.isNotEmpty(id), "请选择菜单");
        sysMenuService.disableMenuByIds(new HashSet<>(Collections.singletonList(id)));
        return new BaseResponse<>(200, "sucess", true);
    }

    /**
     * 禁用菜单多个
     */
    @PostMapping("/disableMenuMulti")
    public BaseResponse disableMenuMulti(@RequestBody List<Long> ids) {
        sysMenuService.disableMenuByIds(new HashSet<Long>(ids));
        return new BaseResponse<>(200, "sucess", true);
    }

}
