package edu.travel.ws.factoryandstragy;

import edu.travel.ws.enums.MessageEnum;
import edu.travel.ws.service.MessageService;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

@Component
public class MessageFactory implements InitializingBean {

    /**
     * 所有的具体支付策略的对象逻辑会被注入到这里
     */
    @Resource
    private List<MessageService> list;

    /**
     * 存储策略标识和具体策略的map
     */
    private Map<MessageEnum, MessageService> handlerMap = new ConcurrentHashMap<>();


    /**
     * 根据枚举的code来获取对应的策略
     *
     * @param code
     * @return
     */
    public MessageService getHandlerByCode(int code) {
        MessageEnum byCode = MessageEnum.getByCode(code);
        return handlerMap.get(byCode);
    }


    @Override
    public void afterPropertiesSet() throws Exception {
        for (MessageService service : list) {
            handlerMap.put(service.getCode(), service);
        }
    }
}
